.. Freezer Disaster Recovery documentation master file, created by
   sphinx-quickstart on Thu Feb  4 22:27:35 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Freezer's Disaster Recovery documentation!
=====================================================

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. toctree::
   :maxdepth: 1

   api/autoindex

.. toctree::
   :hidden: